@@ -2,6 +2,6 @@
 Load networks
 """
 from . import db
-from . import loads
+from . import models
 from . import paper
-__version__ = "0.0.1"
+__version__ = "0.0.3"
